package com.ruoyi.common.k3cloud.service;

import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.google.gson.Gson;
import com.kingdee.bos.webapi.entity.IdentifyInfo;
import com.kingdee.bos.webapi.entity.RepoRet;
import com.kingdee.bos.webapi.sdk.K3CloudApi;
import com.ruoyi.common.exception.ServiceException;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.*;

/**
 * 金蝶Service
 * @author wjh
 * 2024/10/30
 */
@Service
@Slf4j
public class K3Service {

    @Autowired
    private K3CloudApi api;

    public List<JSONArray> selectList(String formId, List<String> fieldKeys, int startRow, int limit) {
        return selectList(formId, fieldKeys, startRow, limit, "", "");
    }

    /**
     * 查询列表
     */
    public List<JSONArray> selectList(String formId, List<String> fieldKeys, int startRow, int limit, String filterString, String orderString) {
        try {
            JSONObject params = new JSONObject();
            params.put("FormId", formId);
            params.put("FieldKeys", String.join(",", fieldKeys));
            params.put("StartRow", startRow);
            params.put("Limit", limit);
            params.put("FilterString", filterString);
            params.put("OrderString", orderString);
            params.put("TopRowCount", 0);
            params.put("SubSystemId", "");
            String res = api.executeBillQueryJson(JSONObject.toJSONString(params));
            if (StringUtils.isBlank(res)) {
                return Collections.emptyList();
            }
            return JSONArray.parseArray(res, JSONArray.class);
        } catch (Exception e) {
            log.error("获取云星空数据失败: formId = {}, message = {}", formId, e.getMessage());
            throw new ServiceException("获取云星空数据失败");
        }
    }

    public <T> T selectOneByNumber(String formId, String number, Class<T> clazz) {
        return selectOne(formId, number, "", "0", false, clazz);
    }
    public <T> T selectOneById(String formId, String id, Class<T> clazz) {
        return selectOne(formId, "", id, "0", false, clazz);
    }

    /**
     * 查看表单内容
     * @param formId 表单类型
     * @param number 单据编号
     * @param id 单据ID
     * @param createOrgId 创建组织
     * @param isSortBySeq
     * @param clazz 返回值类型
     */
    public <T> T selectOne(String formId, String number, String id, String createOrgId, boolean isSortBySeq, Class<T> clazz) {
        try {
            JSONObject params = new JSONObject();
            params.put("CreateOrgId", createOrgId);
            params.put("Number", number);
            params.put("Id", id);
            params.put("IsSortBySeq", isSortBySeq);
            String res = api.view(formId, params.toJSONString());
            if (StringUtils.isBlank(res)) {
                return null;
            }
            return JSONObject.parseObject(res, clazz);
        } catch (Exception e) {
            log.error("获取云星空数据失败: formId = {}, message = {}", formId, e.getMessage());
            throw new ServiceException("获取云星空数据失败");
        }
    }
}
