package com.ruoyi.yh.logImportDetail.service.impl;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.yh.logImportDetail.domain.LogImportDetail;
import com.ruoyi.yh.logImportDetail.domain.LogImportDetailQuery;
import com.ruoyi.yh.logImportDetail.domain.LogImportDetailVO;
import com.ruoyi.yh.logImportDetail.domain.enums.LogImportDetailType;
import com.ruoyi.yh.logImportDetail.domain.vo.LogImportDetailStatisticsByLogIdVO;
import com.ruoyi.yh.logImportDetail.mapper.LogImportDetailMapper;
import com.ruoyi.yh.logImportDetail.service.ILogImportDetailService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 导入日志明细Service业务层处理
 *
 * @author ruoyi
 * @date 2024-11-07
 */
@Service
public class LogImportDetailServiceImpl implements ILogImportDetailService
{
    @Autowired
    private LogImportDetailMapper logImportDetailMapper;

    /**
     * 查询导入日志明细
     *
     * @param detailId 导入日志明细主键
     * @return 导入日志明细
     */
    @Override
    public LogImportDetailVO selectLogImportDetailByDetailId(Long detailId)
    {
        return logImportDetailMapper.selectLogImportDetailByDetailId(detailId);
    }

    /**
     * 查询导入日志明细列表
     *
     * @param logImportDetail 导入日志明细
     * @return 导入日志明细
     */
    @Override
    public List<LogImportDetailVO> selectLogImportDetailList(LogImportDetailQuery logImportDetail)
    {
        return logImportDetailMapper.selectLogImportDetailList(logImportDetail);
    }

    /**
     * 新增导入日志明细
     *
     * @param logImportDetail 导入日志明细
     * @return 结果
     */
    @Override
    public int insertLogImportDetail(LogImportDetail logImportDetail)
    {
        return logImportDetailMapper.insertLogImportDetail(logImportDetail);
    }

    /**
     * 修改导入日志明细
     *
     * @param logImportDetail 导入日志明细
     * @return 结果
     */
    @Override
    public int updateLogImportDetail(LogImportDetail logImportDetail)
    {
        return logImportDetailMapper.updateLogImportDetail(logImportDetail);
    }

    /**
     * 批量删除导入日志明细
     *
     * @param detailIds 需要删除的导入日志明细主键
     * @return 结果
     */
    @Override
    public int deleteLogImportDetailByDetailIds(Long[] detailIds)
    {
        return logImportDetailMapper.deleteLogImportDetailByDetailIds(detailIds);
    }

    /**
     * 删除导入日志明细信息
     *
     * @param detailId 导入日志明细主键
     * @return 结果
     */
    @Override
    public int deleteLogImportDetailByDetailId(Long detailId)
    {
        return logImportDetailMapper.deleteLogImportDetailByDetailId(detailId);
    }


    @Override
    public int addResult(Long logId, LogImportDetailType type, Object content, String message, Long bstId) {
        if (logId == null || type == null || content == null) {
            return 0;
        }
        LogImportDetail data = new LogImportDetail();
        data.setLogId(logId);
        data.setType(type.getType());
        data.setContent(JSON.toJSONString(content));
        data.setMessage(message);
        data.setBstId(bstId);
        return logImportDetailMapper.insertLogImportDetail(data);
    }

    @Override
    public List<LogImportDetailStatisticsByLogIdVO> selectStatisticsGroupByLogId(LogImportDetailQuery query) {
        return logImportDetailMapper.selectStatisticsGroupByLogId(query);
    }
}
