package com.ruoyi.yh.price.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.constant.DictType;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.common.core.interfaces.LogBizParam;
import com.ruoyi.common.core.validate.ValidGroup;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.apache.poi.ss.usermodel.IndexedColors;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.Date;

/**
 * 单价对象 bst_price
 *
 * @author ruoyi
 * @date 2024-10-17
 */
@Data
@EqualsAndHashCode(callSuper = true)
public class Price extends BaseEntity implements LogBizParam
{
    private static final long serialVersionUID = 1L;

    @Excel(name = "ID", prompt = "必填", headerColor = IndexedColors.RED)
    private Long priceId;

    @ApiModelProperty("部门ID")
    @NotNull(message = "部门不存在", groups = ValidGroup.Create.class)
    private Long deptId;

    @Excel(name = "状态", type = Excel.Type.EXPORT, dictType = DictType.PRICE_STATUS, comboReadDict = true, prompt = "必填", headerColor = IndexedColors.RED)
    @ApiModelProperty("状态")
    private String status;

    @Excel(name = "类别")
    @ApiModelProperty("类别")
    @Size(max = 200, message = "类别不允许超过200个字符")
    private String category;

    @Excel(name = "大小")
    @ApiModelProperty("大小")
    @Size(max = 200, message = "大小不允许超过200个字符")
    private String size;

    @Excel(name = "工序名称", prompt = "必填", headerColor = IndexedColors.RED)
    @ApiModelProperty("工序名称")
    @NotNull(message = "工序名称不允许为空", groups = ValidGroup.Create.class)
    @Size(max = 200, message = "工序名称不允许超过200个字符")
    private String name;

    @Excel(name = "子工序名称")
    @ApiModelProperty("子工序名称")
    @Size(max = 200, message = "子工序名称不允许超过200个字符")
    private String subName;

    @Excel(name = "图案")
    @ApiModelProperty("图案")
    @Size(max = 200, message = "图案不允许超过200个字符")
    private String pattern;

    @Excel(name = "规格")
    @ApiModelProperty("规格")
    @Size(max = 200, message = "规格不允许超过200个字符")
    private String spec;

    @Excel(name = "单价(元)")
    @ApiModelProperty("单价")
    @Min(value = 0, message = "单价不允许小于0元")
    private BigDecimal price;

    @Excel(name = "单位")
    @ApiModelProperty("单位")
    @Size(max = 50, message = "单位不允许超过50个字符")
    private String unit;

    @Excel(name = "分类")
    @ApiModelProperty("分类")
    @Size(max = 200, message = "分类不允许超过200个字符")
    private String classify;

    @ApiModelProperty("创建人ID")
    private Long createId;

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "审核时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("审核时间")
    private LocalDateTime verifyTime;

    @ApiModelProperty("审核人ID")
    private Long verifyId;

    @Excel(name = "审核人名称")
    @ApiModelProperty("审核人名称")
    private String verifyBy;

    @ApiModelProperty("更新人ID")
    private Long updateId;

    @Excel(name = "是否禁用", combo = {"是", "否"}, readConverterExp = "true=是,false=否", prompt = "必填", headerColor = IndexedColors.RED)
    @ApiModelProperty("是否禁用")
    private Boolean disabled;

    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "禁用时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("禁用时间")
    private LocalDateTime disabledTime;

    @Excel(name = "生产数量倍数分子(个)", prompt = "必填", headerColor = IndexedColors.RED)
    @ApiModelProperty("生产数量倍数分子(个)")
    @Min(value = 0, message = "生产数量倍数分子不允许小于0")
    private BigDecimal quantityNumerator;

    @Excel(name = "生产数量倍数分母(个)", prompt = "必填", headerColor = IndexedColors.RED)
    @ApiModelProperty("生产数量倍数分母(个)")
    @Min(value = 1, message = "生产数量倍数分母不允许小于1")
    private BigDecimal quantityDenominator;

    /** 创建者 */
    @Excel(name = "创建人")
    private String createBy;

    /** 创建时间 */
    @Excel(name = "创建时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /** 更新者 */
    @Excel(name = "更新人")
    private String updateBy;

    /** 更新时间 */
    @Excel(name = "更新时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    @Excel(name = "备注")
    private String remark;

    @Excel(name = "代码", type = Excel.Type.EXPORT)
    private String code;

    @Excel(name = "表面处理")
    private String surface;

    /**
     * 获取日志业务ID
     */
    @Override
    public Object logBizId() {
        return this.getPriceId();
    }
}
