package com.ruoyi.yh.price.domain.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/10/17
 */
@Getter
@AllArgsConstructor
public enum PriceStatus {

    WAIT_SUBMIT("1", "未提交"),
    WAIT_VERIFY("2", "待审核"),
    PASS("3", "已通过"),
    REJECT("4", "未通过");

    private final String status;
    private final String msg;

    public static List<String> asList(PriceStatus ...statuses) {
        return Arrays.stream(statuses).map(PriceStatus::getStatus).collect(Collectors.toList());
    }

    /**
     * 允许修改的状态
     */
    public static List<String> canEdit() {
        return asList(WAIT_SUBMIT, REJECT);
    }

    /**
     * 允许提交的状态
     */
    public static List<String> canSubmit() {
        return asList(WAIT_SUBMIT);
    }

    /**
     * 允许取消的状态
     */
    public static List<String> canCancel() {
        return asList(WAIT_VERIFY);
    }

    /**
     * 允许审核的状态
     */
    public static List<String> canVerify() {
        return asList(WAIT_VERIFY);
    }

    /**
     * 允许禁用的状态
     */
    public static List<String> canDisable() {
        return asList(PASS);
    }

    /**
     * 允许启用的状态
     */
    public static List<String> canEnable() {
        return asList(PASS);
    }

    /**
     * 允许被报表使用的状态
     */
    public static List<String> canCheckToReport() {
        return asList(PASS, WAIT_VERIFY);
    }

    /**
     * 允许删除的状态
     */
    public static List<String> canDel() {
        return asList(WAIT_SUBMIT, REJECT);
    }

}
