package com.ruoyi.yh.price.mapper;

import java.util.List;

import org.apache.ibatis.annotations.Param;

import com.ruoyi.yh.price.domain.Price;
import com.ruoyi.yh.price.domain.PriceQuery;
import com.ruoyi.yh.price.domain.PriceVO;
import com.ruoyi.yh.price.domain.dto.PricePropertyQuery;
import com.ruoyi.yh.price.domain.vo.PriceColumnCountVO;

/**
 * 单价Mapper接口
 *
 * @author ruoyi
 * @date 2024-10-17
 */
public interface PriceMapper
{
    /**
     * 查询单价
     *
     * @param priceId 单价主键
     * @return 单价
     */
    public PriceVO selectPriceByPriceId(Long priceId);

    /**
     * 查询单价列表
     *
     * @param query 单价
     * @return 单价集合
     */
    public List<PriceVO> selectPriceList(@Param("query")PriceQuery query);

    /**
     * 新增单价
     *
     * @param price 单价
     * @return 结果
     */
    public int insertPrice(Price price);

    /**
     * 修改单价
     *
     * @param price 单价
     * @return 结果
     */
    public int updatePrice(@Param("data") Price price);

    /**
     * 删除单价
     *
     * @param priceId 单价主键
     * @return 结果
     */
    public int deletePriceByPriceId(Long priceId);

    /**
     * 批量删除单价
     *
     * @param priceIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePriceByPriceIds(Long[] priceIds);

    /**
     * 条件更新
     */
    int updateByQuery(@Param("data") Price data, @Param("query") PriceQuery query);

    /**
     * 查询列统计
     */
    List<PriceColumnCountVO> selectColumnCount(@Param("query") PriceQuery query, @Param("column") String column);

    /**
     * 批量审核
     */
    int batchVerify(@Param("list") List<Price> list, @Param("query") PriceQuery query);

    /**
     * 查询数量
     */
    int selectCount(@Param("query") PriceQuery query);

    /**
     * 查询属性值
     */
    List<Object> selectProperty(@Param("query") PricePropertyQuery query);
}
