package com.ruoyi.yh.prodOrder.mapper;

import java.math.BigDecimal;
import java.util.List;

import org.apache.ibatis.annotations.Param;

import com.ruoyi.yh.prodOrder.domain.ProdOrder;
import com.ruoyi.yh.prodOrder.domain.ProdOrderQuery;
import com.ruoyi.yh.prodOrder.domain.ProdOrderVO;

/**
 * 生产订单Mapper接口
 *
 * @author ruoyi
 * @date 2024-10-29
 */
public interface ProdOrderMapper
{
    /**
     * 查询生产订单
     *
     * @param id 生产订单主键
     * @return 生产订单
     */
    public ProdOrderVO selectProdOrderById(Long id);

    /**
     * 查询生产订单列表
     *
     * @param query 生产订单
     * @return 生产订单集合
     */
    public List<ProdOrderVO> selectProdOrderList(@Param("query")ProdOrderQuery query);

    /**
     * 新增生产订单
     *
     * @param prodOrder 生产订单
     * @return 结果
     */
    public int insertProdOrder(ProdOrder prodOrder);

    /**
     * 修改生产订单
     *
     * @param prodOrder 生产订单
     * @return 结果
     */
    public int updateProdOrder(@Param("data") ProdOrder prodOrder);

    /**
     * 删除生产订单
     *
     * @param id 生产订单主键
     * @return 结果
     */
    public int deleteProdOrderById(Long id);

    /**
     * 批量删除生产订单
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteProdOrderByIds(Long[] ids);

    /**
     * 增加已审核通过的基础数量
     * @param orderId 订单ID
     * @param num 基础数量
     */
    int addVerifiedBaseNum(@Param("orderId") Long orderId, @Param("num") BigDecimal num);

    /**
     * 减少已审核通过的基础数量
     * @param orderId 订单ID
     * @param num 基础数量
     */
    int subtractVerifiedBaseNum(@Param("orderId") Long orderId, @Param("num") BigDecimal num);

    /**
     * 查询简单列表
     */
    List<ProdOrderVO> selectSimpleList(@Param("query") ProdOrderQuery query, @Param("fields") List<String> fields);
}
