package com.ruoyi.yh.report.service;

import java.util.List;

import com.ruoyi.yh.report.domain.Report;
import com.ruoyi.yh.report.domain.ReportQuery;
import com.ruoyi.yh.report.domain.ReportVO;
import com.ruoyi.yh.report.domain.bo.ReportBO;
import com.ruoyi.yh.report.domain.dto.ReportVerifyDTO;

/**
 * 报表Service接口
 *
 * @author ruoyi
 * @date 2024-10-18
 */
public interface ReportService
{
    /**
     * 查询报表
     *
     * @param reportId 报表主键
     * @return 报表
     */
    public ReportVO selectReportByReportId(Long reportId);

    /**
     * 查询报表列表
     *
     * @param report 报表
     * @return 报表集合
     */
    public List<ReportVO> selectReportList(ReportQuery report);

    /**
     * 新增报表
     *
     * @param report 报表
     * @return 结果
     */
    public int insertReport(Report report);

    /**
     * 修改报表
     *
     * @param report 报表
     * @return 结果
     */
    public int updateReport(Report report);

    /**
     * 批量删除报表
     *
     * @param reportIds 需要删除的报表主键集合
     * @return 结果
     */
    public int deleteReportByReportIds(Long[] reportIds);

    /**
     * 删除报表信息
     *
     * @param reportId 报表主键
     * @return 结果
     */
    public int deleteReportByReportId(Long reportId);

    /**
     * 新增报表
     */
    int addReport(ReportBO bo);

    /**
     * 修改报表
     * @param bo
     * @return
     */
    int editReport(ReportBO bo);

    /**
     * 审核报表
     * @param dto 审核参数
     * @param verifyId 审核人ID
     */
    int verify(ReportVerifyDTO dto, Long verifyId);

    /**
     * 取消提交
     */
    int cancel(Long reportId);

    /**
     * 提交
     */
    int submit(Long reportId);

    /**
     * 逻辑删除
     */
    int logicDel(List<Long> reportIds);

    /**
     * 查询报表信息
     */
    List<ReportVO> selectByReportIds(List<Long> reportIds);

    /**
     * 根据单价ID，重新计算报表总价
     * @param priceIds 单价ID列表
     */
    int recalculateReportTotalAmountByPriceId(List<Long> priceIds);

    /** 
     * 反审核
     * @param reportId 报表ID
     */
    int unVerify(Long reportId);

    /**
     * 财务审核
     * @param dto 审核参数
     * @param userId 审核人ID
     */
    int financeVerify(ReportVerifyDTO dto, Long userId);
}
