package com.ruoyi.yh.report.service.impl;

import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.vo.LongIntegerVO;
import com.ruoyi.yh.report.domain.ReportVO;
import com.ruoyi.yh.report.service.ReportAssembler;
import com.ruoyi.yh.report.service.ReportService;
import com.ruoyi.yh.reportProd.domain.ReportProdQuery;
import com.ruoyi.yh.reportProd.domain.ReportProdVO;
import com.ruoyi.yh.reportProd.service.ReportProdAssembler;
import com.ruoyi.yh.reportProd.service.ReportProdService;
import com.ruoyi.yh.reportUserProd.service.ReportUserProdAssembler;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author wjh
 * 2024/10/31
 */
@Service
public class ReportAssemblerImpl implements ReportAssembler {

    @Autowired
    private ReportService reportService;

    @Autowired
    private ReportProdService reportProdService;

    @Autowired
    private ReportUserProdAssembler reportUserProdAssembler;

    @Autowired
    private ReportProdAssembler reportProdAssembler;

    @Override
    public void assembleProductList(List<ReportVO> list, boolean assembleUserProd, boolean assembleOrderProd) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        // 查询产量明细
        ReportProdQuery query = new ReportProdQuery();
        query.setReportIds(CollectionUtils.map(list, ReportVO::getReportId));
        List<ReportProdVO> prodList = reportProdService.selectReportProdList(query);

        // 拼接员工产量
        if (assembleUserProd) {
            reportProdAssembler.assembleUserProdList(prodList);
        }
        // 拼接订单产量
        if (assembleOrderProd) {
            reportProdAssembler.assembleOrderProdList(prodList);
        }

        // 分组
        Map<Long, List<ReportProdVO>> group = prodList.stream().collect(Collectors.groupingBy(ReportProdVO::getReportId));

        for (ReportVO report : list) {
            List<ReportProdVO> productList = group.get(report.getReportId());
            if (productList == null) {
                productList = new ArrayList<>();
            }
            report.setProductList(productList);
        }
    }

    @Override
    public void assembleProductCount(List<ReportVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return;
        }
        // 查询产量数量并按报表分组
        ReportProdQuery query = new ReportProdQuery();
        query.setReportIds(CollectionUtils.map(list, ReportVO::getReportId));
        List<LongIntegerVO> prodList = reportProdService.selectCountGroupByReportId(query);

        for (ReportVO report : list) {
            LongIntegerVO vo = prodList.stream().filter(p -> p.getKey().equals(report.getReportId())).findFirst().orElse(null);
            if (vo != null && vo.getValue() != null) {
                report.setProductCount(vo.getValue());
            } else {
                report.setProductCount(0);
            }

        }
    }
}
