package com.ruoyi.yh.report.service.impl;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.MathUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.system.service.ISysDeptService;
import com.ruoyi.yh.price.domain.PriceVO;
import com.ruoyi.yh.price.service.PriceService;
import com.ruoyi.yh.report.domain.ReportVO;
import com.ruoyi.yh.report.domain.bo.ReportBO;
import com.ruoyi.yh.report.domain.enums.ReportStatus;
import com.ruoyi.yh.report.service.ReportConverter;
import com.ruoyi.yh.report.service.ReportService;
import com.ruoyi.yh.reportProd.domain.ReportProdVO;
import com.ruoyi.yh.reportProd.domain.bo.ReportProdBO;
import com.ruoyi.yh.reportProd.service.ReportProdConverter;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * @author wjh
 * 2024/10/31
 */
@Service
public class ReportConverterImpl implements ReportConverter {

    @Autowired
    private ReportService reportService;

    @Autowired
    private ReportProdConverter reportProdConverter;

    @Autowired
    private ISysDeptService deptService;

    @Autowired
    private PriceService priceService;

    @Override
    public ReportBO toBoByCreate(ReportVO vo, boolean submit) {
        if (vo == null) {
            return null;
        }

        SysUser user = SecurityUtils.getLoginUser().getUser();

        // 报表主表数据
        ReportBO bo = new ReportBO();
        bo.setDeptId(vo.getDeptId());
        if (submit) {
            bo.setStatus(ReportStatus.WAIT_VERIFY.getStatus());
        } else {
            bo.setStatus(ReportStatus.WAIT_SUBMIT.getStatus());
        }
        bo.setCreateId(user.getUserId());
        bo.setReportDate(vo.getReportDate());
        bo.setCreateBy(user.getNickName());

        // 查询单价数据
        List<PriceVO> prices = priceService.selectPriceListByIds(CollectionUtils.map(vo.getProductList(), ReportProdVO::getPriceId));

        // 报表产量数据
        List<ReportProdBO> productList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(vo.getProductList())) {
            for (ReportProdVO item : vo.getProductList()) {
                PriceVO price = prices.stream().filter(p -> Objects.equals(p.getPriceId(), item.getPriceId())).findFirst().orElse(null);
                ReportProdBO prodBo = reportProdConverter.toBoByCreate(item, price);
                productList.add(prodBo);
            }
        }

        // 组装数据
        bo.setProductList(productList);
        bo.setDept(deptService.selectDeptById(bo.getDeptId(), true));
        bo.setTotalAmount(this.calculateTotalAmount(bo));
        return bo;
    }

    @Override
    public ReportBO toBoByUpdate(ReportVO vo, boolean submit) {
        if (vo == null) {
            return null;
        }

        SysUser user = SecurityUtils.getLoginUser().getUser();

        // 报表主表数据
        ReportBO bo = new ReportBO();
        bo.setReportId(vo.getReportId());
        bo.setDeptId(vo.getDeptId());
        bo.setReportDate(vo.getReportDate());
        if (submit) {
            bo.setStatus(ReportStatus.WAIT_VERIFY.getStatus());
        }
        bo.setUpdateId(user.getUserId());
        bo.setUpdateBy(user.getNickName());

        // 查询单价数据
        List<PriceVO> prices = priceService.selectPriceListByIds(CollectionUtils.map(vo.getProductList(), ReportProdVO::getPriceId));

        // 报表产量数据
        List<ReportProdBO> productList = new ArrayList<>();
        if (CollectionUtils.isNotEmpty(vo.getProductList())) {
            for (ReportProdVO item : vo.getProductList()) {
                PriceVO price = prices.stream().filter(p -> Objects.equals(p.getPriceId(), item.getPriceId())).findFirst().orElse(null);
                ReportProdBO prodBo = reportProdConverter.toBoByUpdate(item, price);
                productList.add(prodBo);
            }
        }

        // 组装数据
        bo.setProductList(productList);
        bo.setDept(deptService.selectDeptById(bo.getDeptId(), true));
        bo.setOld(reportService.selectReportByReportId(vo.getReportId()));
        bo.setTotalAmount(this.calculateTotalAmount(bo));
        return bo;
    }

    private BigDecimal calculateTotalAmount(ReportBO bo) {
        BigDecimal totalAmount = BigDecimal.ZERO;
        if (CollectionUtils.isNotEmpty(bo.getProductList())) {
            for (ReportProdBO item : bo.getProductList()) {
                totalAmount = MathUtils.addDecimal(totalAmount, item.getTotalAmount());
            }
        }
        return totalAmount;
    }
}
