package com.ruoyi.yh.reportProd.service;

import com.ruoyi.common.vo.LongIntegerVO;
import com.ruoyi.yh.reportProd.domain.ReportProd;
import com.ruoyi.yh.reportProd.domain.ReportProdQuery;
import com.ruoyi.yh.reportProd.domain.ReportProdVO;
import com.ruoyi.yh.reportProd.domain.dto.ReportProdNewPriceDTO;

import java.util.List;

/**
 * 报表产量Service接口
 *
 * @author ruoyi
 * @date 2024-10-31
 */
public interface ReportProdService
{
    /**
     * 查询报表产量
     *
     * @param id 报表产量主键
     * @return 报表产量
     */
    public ReportProdVO selectReportProdById(Long id);

    /**
     * 查询报表产量列表
     *
     * @param reportProd 报表产量
     * @return 报表产量集合
     */
    public List<ReportProdVO> selectReportProdList(ReportProdQuery reportProd);

    /**
     * 新增报表产量
     *
     * @param reportProd 报表产量
     * @return 结果
     */
    public int insertReportProd(ReportProd reportProd);

    /**
     * 修改报表产量
     *
     * @param reportProd 报表产量
     * @return 结果
     */
    public int updateReportProd(ReportProd reportProd);

    /**
     * 批量删除报表产量
     *
     * @param ids 需要删除的报表产量主键集合
     * @return 结果
     */
    public int deleteReportProdByIds(Long[] ids);

    /**
     * 删除报表产量信息
     *
     * @param id 报表产量主键
     * @return 结果
     */
    public int deleteReportProdById(Long id);

    /**
     * 根据报表ID，批量新增产量
     * @param productList 产量列表
     */
    int batchInsert(List<? extends ReportProd> productList);

    /**
     * 根据报表ID，批量修改产量
     *
     * @param list 产量列表
     */
    int batchUpdate(List<? extends ReportProd> list);

    /**
     * 根据报表ID查询列表
     * @param reportId 报表ID
     * @return
     */
    List<ReportProdVO> selectByReportId(Long reportId);

    /**
     * 批量逻辑删除
     */
    int batchLogicDel(List<ReportProdVO> list);

    /**
     * 批量删除
     */
    int logicDelByReportId(Long reportId);

    /**
     * 批量更新单价
     * @param list
     */
    int batchUpdatePrice(List<ReportProdNewPriceDTO> list);

    /**
     * 刷新单价匹配
     * @param ids
     * @return
     */
    int refreshPriceMatch(List<Long> ids);

    /**
     * 重置单价ID
     */
    int resetPriceId(List<Long> ids);

    /**
     * 根据报表ID查询产量数量
     * @param query
     * @return
     */
    List<LongIntegerVO> selectCountGroupByReportId(ReportProdQuery query);
}
