package com.ruoyi.yh.reportProd.service.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.support.TransactionTemplate;

import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;
import com.ruoyi.common.vo.LongIntegerVO;
import com.ruoyi.yh.price.domain.PriceQuery;
import com.ruoyi.yh.price.domain.PriceVO;
import com.ruoyi.yh.price.service.PriceService;
import com.ruoyi.yh.report.service.ReportService;
import com.ruoyi.yh.reportProd.domain.ReportProd;
import com.ruoyi.yh.reportProd.domain.ReportProdQuery;
import com.ruoyi.yh.reportProd.domain.ReportProdVO;
import com.ruoyi.yh.reportProd.domain.dto.ReportProdNewPriceDTO;
import com.ruoyi.yh.reportProd.mapper.ReportProdMapper;
import com.ruoyi.yh.reportProd.service.ReportProdConverter;
import com.ruoyi.yh.reportProd.service.ReportProdService;
import com.ruoyi.yh.reportUserProd.service.ReportUserProdService;

/**
 * 报表产量Service业务层处理
 *
 * @author ruoyi
 * @date 2024-10-31
 */
@Service
public class ReportProdServiceImpl implements ReportProdService
{
    @Autowired
    private ReportProdMapper reportProdMapper;

    @Autowired
    private TransactionTemplate transactionTemplate;

    @Autowired
    private ReportUserProdService reportUserProdService;

    @Autowired
    private ReportService reportService;

    @Autowired
    private PriceService priceService;

    @Autowired
    private ReportProdConverter reportProdConverter;

    /**
     * 查询报表产量
     *
     * @param id 报表产量主键
     * @return 报表产量
     */
    @Override
    public ReportProdVO selectReportProdById(Long id)
    {
        return reportProdMapper.selectReportProdById(id);
    }

    /**
     * 查询报表产量列表
     *
     * @param reportProd 报表产量
     * @return 报表产量
     */
    @Override
    public List<ReportProdVO> selectReportProdList(ReportProdQuery reportProd)
    {
        return reportProdMapper.selectReportProdList(reportProd);
    }

    /**
     * 新增报表产量
     *
     * @param reportProd 报表产量
     * @return 结果
     */
    @Override
    public int insertReportProd(ReportProd reportProd)
    {
        return reportProdMapper.insertReportProd(reportProd);
    }

    /**
     * 修改报表产量
     *
     * @param reportProd 报表产量
     * @return 结果
     */
    @Override
    public int updateReportProd(ReportProd reportProd)
    {
        return reportProdMapper.updateReportProd(reportProd);
    }

    /**
     * 批量删除报表产量
     *
     * @param ids 需要删除的报表产量主键
     * @return 结果
     */
    @Override
    public int deleteReportProdByIds(Long[] ids)
    {
        return reportProdMapper.deleteReportProdByIds(ids);
    }

    /**
     * 删除报表产量信息
     *
     * @param id 报表产量主键
     * @return 结果
     */
    @Override
    public int deleteReportProdById(Long id)
    {
        return reportProdMapper.deleteReportProdById(id);
    }

    @Override
    public int batchInsert(List<? extends ReportProd> productList) {
        if (CollectionUtils.isEmptyElement(productList) ) {
            return 0;
        }
        return reportProdMapper.batchInsert(productList);
    }

    @Override
    public int batchUpdate(List<? extends ReportProd> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        return reportProdMapper.batchUpdate(list);
    }

    @Override
    public List<ReportProdVO> selectByReportId(Long reportId) {
        if (reportId == null) {
            return Collections.emptyList();
        }
        ReportProdQuery query = new ReportProdQuery();
        query.setReportId(reportId);
        return reportProdMapper.selectReportProdList(query);
    }

    @Override
    public int batchLogicDel(List<ReportProdVO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }
        List<Long> ids = list.stream().map(ReportProdVO::getId).filter(Objects::nonNull).collect(Collectors.toList());
        return reportProdMapper.batchLogicDel(ids);
    }

    @Override
    public int logicDelByReportId(Long reportId) {
        if (reportId == null) {
            return 0;
        }
        return reportProdMapper.logicDelByReportId(reportId);
    }

    @Override
    public int batchUpdatePrice(List<ReportProdNewPriceDTO> list) {
        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }

        Integer result = transactionTemplate.execute(status -> {
            int update = reportProdMapper.batchUpdatePrice(list);

            if (update > 0) {
                // 若更新成功，则将对应的报表总价更新
                int calc = reportService.recalculateReportTotalAmountByPriceId(CollectionUtils.map(list, ReportProdNewPriceDTO::getPriceId));
                ServiceUtil.assertion(calc == 0, "更新报表总价失败");
            }

            return update;
        });

        return result == null ? 0 : result;
    }

    @Override
    public int refreshPriceMatch(List<Long> ids) {
        if (CollectionUtils.isEmptyElement(ids)) {
            return 0;
        }

        // 获取未匹配的工序
        List<ReportProdVO> oldList = this.selectByIds(ids).stream()
            .filter(item -> item.getPriceId() == null).collect(Collectors.toList());
        if (CollectionUtils.isEmptyElement(oldList)) {
            return 0;
        }

        // 已匹配的工序
        List<ReportProd> list = new ArrayList<>();

        // 依次匹配工序
        for (ReportProdVO old : oldList) {
            PriceQuery query = new PriceQuery();
            query.setEqName(old.getPriceName());
            query.setEqCategory(old.getPriceCategory());
            query.setEqSize(old.getPriceSize());
            query.setEqPattern(old.getPricePattern());
            query.setDeptId(old.getDeptId());
            query.setNeedAllMatch(true);
            PriceVO price = priceService.selectOne(query);
            if (price == null) {
                continue;
            }
            ReportProd prod = new ReportProd();
            prod.setId(old.getId());
            reportProdConverter.setPriceInfo(prod, price);
            list.add(prod);
        }

        if (CollectionUtils.isEmptyElement(list)) {
            return 0;
        }

        Integer result = transactionTemplate.execute(status -> {
            int update = reportProdMapper.refreshPriceMatch(list);
            if (update > 0) {
                // 若更新成功，则将对应的报表总价更新
                int calc = reportService.recalculateReportTotalAmountByPriceId(CollectionUtils.map(list, ReportProd::getPriceId));
                ServiceUtil.assertion(calc == 0, "更新报表总价失败");
            }
            return update;
        });
        return result == null ? 0 : result;
    }

    @Override
    public int resetPriceId(List<Long> ids) {
        if (CollectionUtils.isEmptyElement(ids)) {
            return 0;
        }
        return reportProdMapper.resetPriceId(ids);
    }

    private List<ReportProdVO> selectByIds(List<Long> ids) {
        if (CollectionUtils.isEmptyElement(ids)) {
            return Collections.emptyList();
        }
        ReportProdQuery query = new ReportProdQuery();
        query.setIds(ids);
        return reportProdMapper.selectReportProdList(query);
    }

    @Override
    public List<LongIntegerVO> selectCountGroupByReportId(ReportProdQuery query) {
        return reportProdMapper.selectCountGroupByReportId(query);
    }
}
