package com.ruoyi.yh.shift.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.yh.shift.domain.Shift;
import com.ruoyi.yh.shift.domain.ShiftQuery;
import com.ruoyi.yh.shift.domain.ShiftVO;
import com.ruoyi.yh.shift.mapper.ShiftMapper;
import com.ruoyi.yh.shift.service.ShiftService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 调班Service业务层处理
 *
 * @author ruoyi
 * @date 2024-12-07
 */
@Service
public class ShiftServiceImpl implements ShiftService
{
    @Autowired
    private ShiftMapper shiftMapper;

    /**
     * 查询调班
     *
     * @param shiftId 调班主键
     * @return 调班
     */
    @Override
    public ShiftVO selectShiftByShiftId(Long shiftId)
    {
        return shiftMapper.selectShiftByShiftId(shiftId);
    }

    /**
     * 查询调班列表
     *
     * @param shift 调班
     * @return 调班
     */
    @Override
    public List<ShiftVO> selectShiftList(ShiftQuery shift)
    {
        return shiftMapper.selectShiftList(shift);
    }

    /**
     * 新增调班
     *
     * @param shift 调班
     * @return 结果
     */
    @Override
    public int insertShift(Shift shift)
    {
        shift.setCreateTime(DateUtils.getNowDate());
        return shiftMapper.insertShift(shift);
    }

    /**
     * 修改调班
     *
     * @param shift 调班
     * @return 结果
     */
    @Override
    public int updateShift(Shift shift)
    {
        shift.setUpdateTime(DateUtils.getNowDate());
        return shiftMapper.updateShift(shift);
    }

    /**
     * 批量删除调班
     *
     * @param shiftIds 需要删除的调班主键
     * @return 结果
     */
    @Override
    public int deleteShiftByShiftIds(Long[] shiftIds)
    {
        return shiftMapper.deleteShiftByShiftIds(shiftIds);
    }

    /**
     * 删除调班信息
     *
     * @param shiftId 调班主键
     * @return 结果
     */
    @Override
    public int deleteShiftByShiftId(Long shiftId)
    {
        return shiftMapper.deleteShiftByShiftId(shiftId);
    }

    @Override
    public int logicDel(List<Long> shiftIds) {
        return shiftMapper.logicDel(shiftIds);
    }

}
