package com.ruoyi.web.yh;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.constant.LogTitle;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.ValidGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.enums.LogBizType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.yh.material.domain.Material;
import com.ruoyi.yh.material.domain.MaterialQuery;
import com.ruoyi.yh.material.domain.MaterialVO;
import com.ruoyi.yh.material.service.MaterialService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 物料Controller
 *
 * @author ruoyi
 * @date 2024-11-12
 */
@RestController
@RequestMapping("/yh/material")
public class MaterialController extends BaseController
{
    @Autowired
    private MaterialService materialService;

    private static final String LOG_TITLE = LogTitle.MATERIAL;

    /**
     * 查询物料列表
     */
    @PreAuthorize("@ss.hasPermi('yh:material:list')")
    @GetMapping("/list")
    public TableDataInfo list(MaterialQuery query)
    {
        startPage();
        startOrderBy();
        List<MaterialVO> list = materialService.selectMaterialList(query);
        return getDataTable(list);
    }

    /**
     * 导出物料列表
     */
    @PreAuthorize("@ss.hasPermi('yh:material:export')")
    @Log(title = LOG_TITLE, businessType = BusinessType.EXPORT, bizType = LogBizType.MATERIAL)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MaterialQuery query)
    {
        startPage();
        List<MaterialVO> list = materialService.selectMaterialList(query);
        ExcelUtil<MaterialVO> util = new ExcelUtil<MaterialVO>(MaterialVO.class);
        util.exportExcel(response, list, "物料数据");
    }

    /**
     * 获取物料详细信息
     */
    @PreAuthorize("@ss.hasPermi('yh:material:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(materialService.selectMaterialById(id));
    }

    /**
     * 新增物料
     */
    @PreAuthorize("@ss.hasPermi('yh:material:add')")
    @Log(title = LOG_TITLE, businessType = BusinessType.INSERT, bizType = LogBizType.MATERIAL, bizIdName = "arg0")
    @PostMapping
    public AjaxResult add(@RequestBody @Validated(ValidGroup.Create.class) Material material)
    {
        return toAjax(materialService.insertMaterial(material));
    }

    /**
     * 修改物料
     */
    @PreAuthorize("@ss.hasPermi('yh:material:edit')")
    @Log(title = LOG_TITLE, businessType = BusinessType.UPDATE, bizType = LogBizType.MATERIAL, bizIdName = "arg0")
    @PutMapping
    public AjaxResult edit(@RequestBody @Validated(ValidGroup.Update.class) Material material)
    {
        return toAjax(materialService.updateMaterial(material));
    }

    /**
     * 删除物料
     */
    @PreAuthorize("@ss.hasPermi('yh:material:remove')")
    @Log(title = LOG_TITLE, businessType = BusinessType.DELETE, bizType = LogBizType.MATERIAL, bizIdName = "arg0")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(materialService.deleteMaterialByIds(ids));
    }


    @PreAuthorize("@ss.hasPermi('yh:material:sync')")
    @Log(title = LOG_TITLE, businessType = BusinessType.SYNC, bizType = LogBizType.MATERIAL)
    @PutMapping("/sync")
    public AjaxResult sync() {
        materialService.sync(getUserId());
        return success();
    }
}
