package com.ruoyi.web.yh;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.constant.LogTitle;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.enums.LogBizType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.yh.prodOrder.domain.ProdOrder;
import com.ruoyi.yh.prodOrder.domain.ProdOrderQuery;
import com.ruoyi.yh.prodOrder.domain.ProdOrderVO;
import com.ruoyi.yh.prodOrder.domain.dto.ProdOrderSyncQuery;
import com.ruoyi.yh.prodOrder.domain.enums.ProdOrderErpStatus;
import com.ruoyi.yh.prodOrder.service.ProdOrderService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 生产订单Controller
 *
 * @author ruoyi
 * @date 2024-10-29
 */
@RestController
@RequestMapping("/yh/prodOrder")
public class ProdOrderController extends BaseController
{
    @Autowired
    private ProdOrderService prodOrderService;

    /**
     * 查询生产订单列表
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProdOrderQuery query)
    {
        startPage();
        startOrderBy();
        query.setUserDeptId(getDeptId());
        List<ProdOrderVO> list = prodOrderService.selectProdOrderList(query);
        return getDataTable(list);
    }
    /**
     * 查询生产订单列表ByIds
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:list')")
    @PostMapping("/listByIds")
    public AjaxResult list(@RequestBody List<Long> ids)
    {
        ProdOrderQuery query = new ProdOrderQuery();
        query.setIds(ids);
        query.setUserDeptId(getDeptId());
        List<ProdOrderVO> list = prodOrderService.selectProdOrderList(query);
        return success(list);
    }

    /**
     * 导出生产订单列表
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:export')")
    @Log(title = LogTitle.PROD_ORDER, businessType = BusinessType.EXPORT, bizType = LogBizType.PROD_ORDER)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdOrderQuery query)
    {
        startPage();
        List<ProdOrderVO> list = prodOrderService.selectProdOrderList(query);
        ExcelUtil<ProdOrderVO> util = new ExcelUtil<ProdOrderVO>(ProdOrderVO.class);
        util.exportExcel(response, list, "生产订单数据");
    }

    /**
     * 获取生产订单详细信息
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        ProdOrderVO detail = prodOrderService.selectProdOrderById(id);
        return success(detail);
    }

    /**
     * 新增生产订单
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:add')")
    @Log(title = LogTitle.PROD_ORDER, businessType = BusinessType.INSERT, bizType = LogBizType.PROD_ORDER, bizIdName = "arg0")
    @PostMapping
    public AjaxResult add(@RequestBody ProdOrder prodOrder)
    {
        return toAjax(prodOrderService.insertProdOrder(prodOrder));
    }

    /**
     * 修改生产订单
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:edit')")
    @Log(title = LogTitle.PROD_ORDER, businessType = BusinessType.UPDATE, bizType = LogBizType.PROD_ORDER, bizIdName = "arg0")
    @PutMapping
    public AjaxResult edit(@RequestBody ProdOrder prodOrder)
    {
        return toAjax(prodOrderService.updateProdOrder(prodOrder));
    }

    /**
     * 删除生产订单
     */
    @PreAuthorize("@ss.hasPermi('yh:prodOrder:remove')")
    @Log(title = LogTitle.PROD_ORDER, businessType = BusinessType.DELETE, bizType = LogBizType.PROD_ORDER, bizIdName = "arg0")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(prodOrderService.deleteProdOrderByIds(ids));
    }

    @PreAuthorize("@ss.hasPermi('yh:prodOrder:sync')")
    @Log(title = LogTitle.PROD_ORDER, businessType = BusinessType.SYNC, bizType = LogBizType.PROD_ORDER)
    @PutMapping("/sync")
    public AjaxResult sync(@RequestBody ProdOrderSyncQuery query) {
        query.setStatusList(ProdOrderErpStatus.canSync());
        prodOrderService.sync(query, getUserId());
        return success();
    }

}
