package com.ruoyi.web.yh;

import java.util.List;

import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.yh.verify.domain.Verify;
import com.ruoyi.yh.verify.domain.VerifyQuery;
import com.ruoyi.yh.verify.domain.VerifyVO;
import com.ruoyi.yh.verify.service.VerifyService;

/**
 * 审核记录Controller
 *
 * @author ruoyi
 * @date 2025-04-01
 */
@RestController
@RequestMapping("/yh/verify")
public class VerifyController extends BaseController
{
    @Autowired
    private VerifyService verifyService;

    /**
     * 查询审核记录列表
     */
    @PreAuthorize("@ss.hasPermi('yh:verify:list')")
    @GetMapping("/list")
    public TableDataInfo list(VerifyQuery query)
    {
        startPage();
        startOrderBy();
        List<VerifyVO> list = verifyService.selectVerifyList(query);
        return getDataTable(list);
    }

    /**
     * 导出审核记录列表
     */
    @PreAuthorize("@ss.hasPermi('yh:verify:export')")
    @Log(title = "审核记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, VerifyQuery query)
    {
        List<VerifyVO> list = verifyService.selectVerifyList(query);
        ExcelUtil<VerifyVO> util = new ExcelUtil<VerifyVO>(VerifyVO.class);
        util.exportExcel(response, list, "审核记录数据");
    }

    /**
     * 获取审核记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('yh:verify:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(verifyService.selectVerifyById(id));
    }

    /**
     * 新增审核记录
     */
    @PreAuthorize("@ss.hasPermi('yh:verify:add')")
    @Log(title = "审核记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Verify verify)
    {
        return toAjax(verifyService.insertVerify(verify));
    }

    /**
     * 修改审核记录
     */
    @PreAuthorize("@ss.hasPermi('yh:verify:edit')")
    @Log(title = "审核记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Verify verify)
    {
        return toAjax(verifyService.updateVerify(verify));
    }

    /**
     * 删除审核记录
     */
    @PreAuthorize("@ss.hasPermi('yh:verify:remove')")
    @Log(title = "审核记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(verifyService.deleteVerifyByIds(ids));
    }
}
